@@ -1,15 +1,8 @@
 from json import loads
 import os
-import sys
-import pathlib
 
-print(pathlib.Path(__file__).parent.absolute())
-print("1" + os.path.dirname(os.path.realpath(__file__)))
-print("2" + sys.path[0])
-print("3" + os.path.dirname(os.path.realpath(sys.argv[0])))
-print("4" + os.path.dirname(__file__))
-print("5" + os.path.realpath(__file__))
-print("6" + os.path.abspath(os.path.dirname(__file__)))
+print(os.path.join(os.path.dirname(__file__), "nk3.json"))
+
 
 def nori(args):
     verb = None
